@@ -12,7 +12,8 @@ def softmax(tensor) -> np.ndarray:
 
 def tpu_tensor_to_num_classes(tensor: np.ndarray, top: int = 1) -> np.ndarray:
     """Get top N classes of output tensor."""
-    num_classes = tensor.flatten().argsort()[::-1][:top]
+    tensor = np.reshape(tensor, (tensor.shape[0], tensor.shape[-1]))
+    num_classes = np.squeeze(tensor.argsort()[::, -top:])
     return num_classes
 
 
